==> PPDF_1_2.zip: PubMedPDF/modify_wopmid.php <==
<?php
	include "header.php";
	include "include/db.php";
	include "style.php";
	include "include/xml.php";

	$up_pass = $xoopsModuleConfig['updir'];
	if(substr($up_pass,-1) != "/") $up_pass.="/";
	$PDFdir = $up_pass."/wopmid/";	
	if(substr($PDFdir,-1) != "/") $PDFdir.="/";
	$XMLdir = "uploads_xml/";
	if(substr($XMLdir,-1) != "/") $XMLdir.="/";

	// Get registered information

	$id = @$_POST["id"];
	$sql = "SELECT * FROM ".$T_ID." WHERE id=$id";
	$res = mysql_query($sql, $conn);

	if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
	$item = array("a"=>$row["Author"], "t"=>$row["Title"], "v"=>$row["Volume"], "p"=>$row["Page"], "y"=>$row["Year"], "ab"=>$row["Abstract"], "j"=>$row["Journal"]);

	// Get author
	$a = $item[a];
	$author="";
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$a[$k] = str_replace("[","",$a[$k]);
		$a[$k] = str_replace("]","",$a[$k]);
		$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author.=$row["Author"].", ";
	}
	$author = substr($author,0,-2);

	// Get journal
	$j = $item[j];
	$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$j."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	// File names
	$old_file = @$_POST["c_t1"];

	// Remove registered information

	if(@$_POST["remove"]){
		echo "<b>Title: </b>".$item[t]."<br>";
		echo "<b>Author(s): </b>".$author."<br>";
		echo "<b>Journal/Book: </b>".$journal."<br>";
		echo "<b>Volume: </b>".$item[v]."<br>";
		echo "<b>Pages: </b>".$item[p]."<br>";
		echo "<b>Year: </b>".$item[y]."<br>";
		echo "<b>Abstract: </b><br>".$item[ab]."<br>";

		$sql = "DELETE FROM ".$T_ID." WHERE id=$id;";
		$res = mysql_query($sql, $conn);
		if( $res ) {
			echo "remove above record<br>";
		} else {
			echo "ERROR: could not remove record<br>";
		}

		rmJournal( $conn, $T_ID, $T_JOURNAL, $j );
		$a = $item[a];
		rmAuthor( $conn, $T_ID, $T_AUTHOR, $a );

		// remove PDF & XML files

		$PDFfile_name = $old_file.".pdf";
		$XMLfile_name = $old_file.".xml";
		if (file_exists($PDFdir.$PDFfile_name) ) {
			unlink( $PDFdir.$PDFfile_name );
			echo "Remove PDF file: $PDFdir.$PDFfile_name<br>";
		}

		unlink( $XMLdir.$XMLfile_name );
		echo "Remove XML file: $XMLdir.$XMLfile_name<br>";
	}

// modify information
	if(@$_POST["modify"]){

		$data[t] = trim(@$_POST["title_e"]);
		$data[t_jp] = trim(@$_POST["title_o"]);
		$data[a] = trim(@$_POST["author_e"]);
		$data[a_jp] = trim(@$_POST["author_o"]);
		$data[v] = trim(@$_POST["volume"]);
		$data[p] = trim(@$_POST["page"]);
		$data[ab] = trim(@$_POST["abstract"]);

		$data[t] = str_replace( "'", "&#8242;", $data[t] );
		$data[t_jp] = str_replace( "'", "&#8242;", $data[t_jp] );
		$data[a] = str_replace( "'", "&#8242;", $data[a] );
		$data[a_jp] = str_replace( "'", "&#8242;", $data[a_jp] );

		if(@$_POST["jb"] == "j"){
			if ( @$_POST["selectedJournal0"] != "(unknown)" ) {
				$data[j] = @$_POST["selectedJournal0"] ;
			} else {
				$data[j] = "(unknown)";
			}
		}elseif(@$_POST["jb"] == "b"){
			if ( @$_POST["selectedJournal1"] != "(unknown)" ) {
				$data[j] = @$_POST["selectedJournal1"] ;
			} else {
				$data[j] = "(unknown)";
			}
		}

		$year = trim(@$_POST["year"]);
		if (  strlen($year) >= 1 ) {
			$data[y] = $year;
		} else {
			if ( @$_POST["selectedYear"] != 0 ) {
				$data[y] = @$_POST["selectedYear"] ;
			} else {
				$data[y] = "0000";
			}
		}

		$title = trim( $data[t] );
		$title = substr( $title, 0, 10 );
		
		$Author = "";
		$Authors = explode(",",$data[a]);
		foreach($Authors as $a){
			$a = trim($a);
			$Author .= $a.", ";
		}
		$data[a] = substr($Author, 0, -2);
		
		$file_name = $data[y]."_".$data[a]."_".$data[j]."_"
					.$data[v]."_".$data[p]."_".$title;
		$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
		$data[c_t1] = $file_name;

		MOD_DB( $id, $data );

		echo "<br><div class=\"pt\">Updated information</div>";

#		echo "<b>ID: </b>".$id."<br>";
		echo "<b>Title: </b>".$data[t]."<br>";
		echo "<b>Author(s): </b>".$data[a]."<br>";
		echo "<b>Journal/Book: </b>".$data[j]."<br>";
		echo "<b>Volume: </b>".$data[v]."<br>";
#		echo "<b>Number: </b>".@$_POST["number"]."<br>";
		echo "<b>Pages: </b>".$data[p]."<br>";
		echo "<b>Year: </b>".$data[y]."<br>";
		echo "<b>Abstract: </b><br>".$data[ab]."<br>";

		# folder for uploaded file

		$oldPDFfile_name = $old_file.".pdf";
		$oldXMLfile_name = $old_file.".xml";

		$PDFfile_name = $file_name.".pdf";
		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];
			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				copy($_FILES['userfile']['tmp_name'], $PDFdir.$PDFfile_name);
				echo "<b>Upload file: </b> [$PDFfile_name] was uploaded.<br><br>";
			}else{
				echo "error: Extension of filename should be \".pdf\".<br>";
			}
		}else{
			if ( file_exists($PDFdir.$oldPDFfile_name) ) {
				rename( $PDFdir.$oldPDFfile_name, $PDFdir.$PDFfile_name );
				echo "<b>Rename PDF file: </b> $oldPDFfile_name -> $PDFfile_name<br>";
			} else {
				echo "<b>Upload file:</b> No upload file<br>";
			}
		}

		unlink( $XMLdir.$oldXMLfile_name );
		GENERATE_XML($data);

		rmJournal( $conn, $T_ID, $T_JOURNAL, $item[j] );
		rmAuthor( $conn, $T_ID, $T_AUTHOR, $item[a] );

	}
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");

//
// Functions
//

function rmJournal( $conn, $T_ID, $T_JOURNAL, $j ) {
	$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$j."';";
	$res = mysql_query($sql, $conn);
	$num = mysql_num_rows($res);

	$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$j."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	if ( $num == 0 ) {
		$sql = "DELETE FROM ".$T_JOURNAL." WHERE id=$j;";
		$res = mysql_query($sql, $conn);
		echo "<b>Remove journal: </b>".$journal."<br>";
	}
}

function rmAuthor( $conn, $T_ID, $T_AUTHOR, $a ) {
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$sql = "SELECT * FROM ".$T_ID." WHERE Author LIKE '%".$a[$k]."%';";
		$res = mysql_query($sql, $conn);
		$num = mysql_num_rows($res);
		if ( $num == 0 ) {
			$a[$k] = str_replace("[","",$a[$k]);
			$a[$k] = str_replace("]","",$a[$k]);
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$author = $row["Author"];

			$sql = "DELETE FROM ".$T_AUTHOR." WHERE id=$a[$k];";
			$res = mysql_query($sql, $conn);
			echo "<b>Remove author: </b>".$author."<br>";
		}
	}
}

?>

==> PPDF_1_3_1.zip: PubMedPDF/modify_wopmid.php <==
<?php
	include "header.php";
	include "include/db.php";
	include "style.php";
	include "include/xml.php";
	include "include/wopmid.php";

	$up_pass = $xoopsModuleConfig['updir'];
	if(substr($up_pass,-1) != "/") $up_pass.="/";
	if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);

	$PDFdir = $up_pass."wopmid/";	
	if(substr($PDFdir,-1) != "/") $PDFdir.="/";
	if(!is_dir($PDFdir))	$rc = mkdir($PDFdir, 0777);

	$XMLdir = "uploads_xml/";
	if(substr($XMLdir,-1) != "/") $XMLdir.="/";
	if(!is_dir($XML_dir))	$rc = mkdir($XML_dir, 0777);

	// Get registered information

	$id = @$_POST["id"];
	$sql = "SELECT * FROM ".$T_ID." WHERE id=$id";
	$res = mysql_query($sql, $conn);

	if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
	$item = array("a"=>$row["Author"], "t"=>$row["Title"], "v"=>$row["Volume"], "p"=>$row["Page"], "y"=>$row["Year"], "ab"=>$row["Abstract"], "j"=>$row["Journal"]);

	// Get author
	$a = $item[a];
	$author="";
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$a[$k] = str_replace("[","",$a[$k]);
		$a[$k] = str_replace("]","",$a[$k]);
		$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author.=$row["Author"].", ";
	}
	$author = substr($author,0,-2);

	// Get journal
	$j = $item[j];
	$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$j."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	// File names
	//$old_file = @$_POST["c_t1"];
	$title = trim( $item[t] );
//	$title = substr( $title, 0, 10 );

/*
 	$old_file = $item[y]."_".$author."_".$journal."_"
		   .$item[v]."_".$item[p]."_".$title;
	$old_file = str_replace( array(' ', ','), array('_', '~'), $old_file );
*/
	$old_file = wopmid($item[y], $author, $journal, $item[v], $item[p], $title);
	
	// Remove registered information

	if(@$_POST["remove"]){
		echo "<b>Title: </b>".$item[t]."<br>";
		echo "<b>Author(s): </b>".$author."<br>";
		echo "<b>Journal/Book: </b>".$journal."<br>";
		echo "<b>Volume: </b>".$item[v]."<br>";
		echo "<b>Pages: </b>".$item[p]."<br>";
		echo "<b>Year: </b>".$item[y]."<br>";
		echo "<b>Abstract: </b><br>".$item[ab]."<br>";

		$sql = "DELETE FROM ".$T_ID." WHERE id=$id;";
		$res = mysql_query($sql, $conn);
		if( $res ) {
			echo "remove above record<br>";
		} else {
			echo "ERROR: could not remove record<br>";
		}

		rmJournal( $conn, $T_ID, $T_JOURNAL, $j );
		$a = $item[a];
		rmAuthor( $conn, $T_ID, $T_AUTHOR, $a );

		// remove PDF & XML files

		$PDFfile_name = $old_file.".pdf";
		$XMLfile_name = $old_file.".xml";
		if (file_exists($PDFdir.$PDFfile_name) ) {
			unlink( $PDFdir.$PDFfile_name );
			echo "Remove PDF file: $PDFdir.$PDFfile_name<br>";
		}

		unlink( $XMLdir.$XMLfile_name );
		echo "Remove XML file: $XMLdir.$XMLfile_name<br>";
	}

// modify information
	if(@$_POST["modify"]){

		$data[t] = trim(@$_POST["title_e"]);
		$data[t_jp] = trim(@$_POST["title_o"]);
		$data[a] = trim(@$_POST["author_e"]);
		$data[a_jp] = trim(@$_POST["author_o"]);
		$data[v] = trim(@$_POST["volume"]);
		$data[p] = trim(@$_POST["page"]);
		$data[ab] = trim(@$_POST["abstract"]);

		foreach($data as $key => $value){
			$data[$key] = str_replace("\"", "&#34;", $data[$key]);
		}

		if(@$_POST["jb"] == "j"){
			if ( @$_POST["selectedJournal0"] != "(unknown)" ) {
				$data[j] = @$_POST["selectedJournal0"] ;
			} else {
				$data[j] = "(unknown)";
			}
		}elseif(@$_POST["jb"] == "b"){
			if ( @$_POST["selectedJournal1"] != "(unknown)" ) {
				$data[j] = @$_POST["selectedJournal1"] ;
			} else {
				$data[j] = "(unknown)";
			}
		}

		$year = trim(@$_POST["year"]);
		if (  strlen($year) >= 1 ) {
			$data[y] = $year;
		} else {
			if ( @$_POST["selectedYear"] != 0 ) {
				$data[y] = @$_POST["selectedYear"] ;
			} else {
				$data[y] = "0000";
			}
		}

		$title = trim( $data[t] );
//		$title = substr( $title, 0, 10 );
		
		$Author = "";
		$Authors = explode(",",$data[a]);
		foreach($Authors as $a){
			$a = trim($a);
			$Author .= $a.", ";
		}
		$data[a] = substr($Author, 0, -2);

/*		
 		$file_name = $data[y]."_".$data[a]."_".$data[j]."_"
					.$data[v]."_".$data[p]."_".$title;
		$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
*/
		$file_name = wopmid($data[y], $data[a], $data[j], $data[v], $data[p], $title);

		$data[c_t1] = $file_name;

		# folder for uploaded file

		$oldXMLfile_name = $old_file.".xml";
		$oldPDFfile_name = $old_file.".pdf";

		$xmlFileName = $file_name.".xml";
		$pdfFileName = $file_name.".pdf";

		// --> added by H.Ikeno 2005/04/25

		if( file_exists($XMLdir.$xmlFileName) ) {
		   echo "<br>Error: Conflict with already regisred information<br>";
		} else {
		   MOD_DB( $id, $data );

		   echo "<br><div class=\"pt\">Updated information</div>";

		   echo "<b>Title: </b>".$data[t]."<br>";
		   echo "<b>Author(s): </b>".$data[a]."<br>";
		   echo "<b>Journal/Book: </b>".$data[j]."<br>";
		   echo "<b>Volume: </b>".$data[v]."<br>";
		   echo "<b>Pages: </b>".$data[p]."<br>";
		   echo "<b>Year: </b>".$data[y]."<br>";
		   echo "<b>Abstract: </b><br>".$data[ab]."<br>";

		   // generate XML file

		   unlink( $XMLdir.$oldXMLfile_name );
		   echo "<b>Rmoved XML file: </b>".$XMLdir.$oldXMLfile_name."<br>";
		   GENERATE_XML($data);
		   echo "<b>Generated XML file</b><br>";

		   // rename PDF file

 		   if( file_exists($PDFdir.$oldPDFfile_name) ) {
		       rename( $PDFdir.$oldPDFfile_name, $PDFdir.$pdfFileName );
		       echo "<b>Renamed PDF file:</b>".$PDFdir.$oldPDFfile_name.
		            " -> ".$PDFdir.$pdfFileName."<br>";
		   }
		}

		rmJournal( $conn, $T_ID, $T_JOURNAL, $item[j] );
		rmAuthor( $conn, $T_ID, $T_AUTHOR, $item[a] );

	}

// upload PDF file
	if(@$_POST["upload"]){
		$PDFfile_name = $old_file.".pdf";

		// upload PDF file

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];
			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				copy($_FILES['userfile']['tmp_name'], $PDFdir.$PDFfile_name);
				echo "<b>Upload file: </b> [$PDFfile_name] was uploaded.<br><br>";
			}else{
				echo "error: Extension of filename should be \".pdf\".<br>";
			}
		}else{
			echo "<b>Upload file:</b> No upload file<br>";
		}

        }
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");

//
// Functions
//

function rmJournal( $conn, $T_ID, $T_JOURNAL, $j ) {
	$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$j."';";
	$res = mysql_query($sql, $conn);
	$num = mysql_num_rows($res);

	$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE id='".$j."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	if ( $num == 0 ) {
		$sql = "DELETE FROM ".$T_JOURNAL." WHERE id=$j;";
		$res = mysql_query($sql, $conn);
		echo "<b>Remove journal: </b>".$journal."<br>";
	}
}

function rmAuthor( $conn, $T_ID, $T_AUTHOR, $a ) {
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$sql = "SELECT * FROM ".$T_ID." WHERE Author LIKE '%".$a[$k]."%';";
		$res = mysql_query($sql, $conn);
		$num = mysql_num_rows($res);
		if ( $num == 0 ) {
			$a[$k] = str_replace("[","",$a[$k]);
			$a[$k] = str_replace("]","",$a[$k]);
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$author = $row["Author"];

			$sql = "DELETE FROM ".$T_AUTHOR." WHERE id=$a[$k];";
			$res = mysql_query($sql, $conn);
			echo "<b>Remove author: </b>".$author."<br>";
		}
	}
}

?>
